<?php

class landingsBlockHelloWorld extends landingsBlock
{
	static public function getInfo()
    {
        return array(
            'code' => 'helloWorld', // Идентификатор блока, горбатым стилем
            'type' => self::TYPE_CONTENT, // Тип блока
            'name' => 'Мой супер-блок', // Имя блока
            'description' => 'Будет делать все, что нужно, когда мы закончим с ним', // Описание блока
            'icon' => wa()->getAppStaticUrl('landings').'plugins/tblock/img/hello-world.png', // URL логотипа блока, 96x96px
        );
    }
	
	// Указывает блоку использовать файл ​​/tblock/templates/blocks/helloWorld/Settings.html как настройки
	public function getSettingsTemplatePath()
	{
		if(!$this->exists()) {return wa()->getAppPath('templates/blocks/default/Settings.html', 'landings');}
		$path = wa()->getAppPath('plugins/tblock/templates/blocks/'.$this->data['code'].'/Settings.html', 'landings');
		if(!file_exists($path)) {return wa()->getAppPath('templates/blocks/default/Settings.html', 'landings');}
		return $path;
	}
	
	// Указывает блоку использовать файл ​​/tblock/templates/blocks/helloWorld/Frontend.html как настройки
	public function getFrontendTemplatePath()
	{
		if(!$this->exists()) {return wa()->getAppPath('templates/blocks/default/Frontend.html', 'landings');}
		return wa()->getAppPath('plugins/tblock/templates/blocks/'.$this->data['code'].'/Frontend.html', 'landings');
	}
	
	// Указывает блоку использовать файл ​​/tblock/css/blocks/helloWorld/frontend.css как css-файл фронтенда
	public function getFrontendCssPath()
	{
		if(!$this->exists()) {return wa()->getAppPath('css/blocks/default/frontend.css', 'landings');}
		return wa()->getAppPath('plugins/tblock/css/blocks/'.$this->data['code'].'/frontend.css', 'landings');
	}
	
	// Указывает блоку использовать файл ​​/tblock/js/blocks/helloWorld/frontend.js как js-файл фронтенда
	public function getFrontendJsPath()
	{
		if(!$this->exists()) {return wa()->getAppPath('js/blocks/default/frontend.js', 'landings');}
		return wa()->getAppPath('plugins/tblock/js/blocks/'.$this->data['code'].'/frontend.js', 'landings');
	}

	// Стандартные настройки блока
	public function getDefaultSettings()
	{
		return array(
			'background_color' => '#ebebeb',
			'text_color' => '#393939',
			'my_custom_setting' => '0',
		);
	}
	
	// Функция для формирования шаблона настроек
	public function getSettingsHtml()
	{
		if(!$this->id) {return '';}
		$view = wa()->getView();
		$view->assign('block_id', $this->id);
		
		$settings = $this->getSettings();
		$view->assign('settings', $settings);
		
		// Дополнительно передадим информацию о блоке
		$view->assign('myCustomInfo', static::getInfo());
		
		return $view->fetch($this->getSettingsTemplatePath());
	}
	
	// Карта выполнения бекенд-функций
	public function execMap()
	{
		return array(
			'myCustom' => 'myCustomSettingsSave',
		);
	}

	// Особый обработчик для сохранения настроек
	public function myCustomSettingsSave()
	{
		$setting = waRequest::post('my_custom_setting', '', 'string');
		// Тут можно добавить любой код для обработки
		return array('result' => 1, 'message' => 'Отлично, сохранили настройку, значение:'.htmlspecialchars($setting, ENT_QUOTES));
	}
	
	// Функция для формирования шаблона фронтенда
	public function getFrontendHtml()
	{
		if(!$this->id) {return '';}
		$view = wa()->getView();
		
		$settings = $this->getSettings();
		// Здесь блок получает унаследованные цвета, если требуется
		$settings = $this->applyLegacyColors($settings);
		
		$view->assign('block_id', $this->id);
		$view->assign('block_data', $this->data);
		$view->assign('block_settings', $settings);
		
		// Дополнительно передадим собственную переменную
		$view->assign('my_custom_variable', 'test');
		$view->assign('form_url', $this->getRouteUrl('receiveRequest'));
		
		// Это правило замены идентификторов в CSS
		$css = str_replace('#landings_block_ ', '#landings_block_'.$this->id.' ', $this->data['css']);
		return $view->fetch('string:'.$this->data['html'].'<script type="text/javascript">'.$this->data['js'].'</script>').'<style type="text/css">'.$css.'</style>';
	}
	
	// Карта выполнения фронтенд-функций
	public function frontendExecMap()
	{
		return array(
			'receive' => 'receiveRequest',
		);
	}
	
	// Функция приема запроса от пользователя
	public function receiveRequest()
	{
		$setting = waRequest::post('my_custom_setting', '', 'string');
		// Тут можно добавить любой код для обработки
		return array('result' => 1, 'message' => 'Отлично, приняли данные, значение:'.htmlspecialchars($setting, ENT_QUOTES));
	}
	
	// Функция определения цветов блока
	public function getColors()
	{
		return array(
			'background_color' => array(
				'name' => 'Цвет фона',
				'hint' => 'Цвет фона блока',
				'legacy' => 'background_primary',
			),
			'text_color' => array(
				'name' => 'Цвет текста',
				'hint' => 'Цвет текста в блоке',
				'legacy' => 'color_primary',
			),
		);
	}
}